@@ -50,9 +50,76 @@ class TranslationServiceAsyncClient:
     glossary_path = staticmethod(TranslationServiceClient.glossary_path)
     parse_glossary_path = staticmethod(TranslationServiceClient.parse_glossary_path)
 
-    from_service_account_file = TranslationServiceClient.from_service_account_file
+    common_billing_account_path = staticmethod(
+        TranslationServiceClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        TranslationServiceClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(TranslationServiceClient.common_folder_path)
+    parse_common_folder_path = staticmethod(
+        TranslationServiceClient.parse_common_folder_path
+    )
+
+    common_organization_path = staticmethod(
+        TranslationServiceClient.common_organization_path
+    )
+    parse_common_organization_path = staticmethod(
+        TranslationServiceClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(TranslationServiceClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        TranslationServiceClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(TranslationServiceClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        TranslationServiceClient.parse_common_location_path
+    )
+
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TranslationServiceAsyncClient: The constructed client.
+        """
+        return TranslationServiceClient.from_service_account_info.__func__(TranslationServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+        file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TranslationServiceAsyncClient: The constructed client.
+        """
+        return TranslationServiceClient.from_service_account_file.__func__(TranslationServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> TranslationServiceTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            TranslationServiceTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(TranslationServiceClient).get_transport_class,
         type(TranslationServiceClient),
@@ -123,7 +190,7 @@ class TranslationServiceAsyncClient:
         r"""Translates input text and returns translated text.
 
         Args:
-            request (:class:`~.translation_service.TranslateTextRequest`):
+            request (:class:`google.cloud.translate_v3.types.TranslateTextRequest`):
                 The request object. The request message for synchronous
                 translation.
             parent (:class:`str`):
@@ -143,6 +210,7 @@ class TranslationServiceAsyncClient:
                 Models and glossaries must be within the same region
                 (have same location-id), otherwise an INVALID_ARGUMENT
                 (400) error is returned.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -151,6 +219,7 @@ class TranslationServiceAsyncClient:
                 use for translation of the input text,
                 set to one of the language codes listed
                 in Language Support.
+
                 This corresponds to the ``target_language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -159,6 +228,7 @@ class TranslationServiceAsyncClient:
                 string format. We recommend the total
                 content be less than 30k codepoints. Use
                 BatchTranslateText for larger text.
+
                 This corresponds to the ``contents`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -181,6 +251,7 @@ class TranslationServiceAsyncClient:
 
                 If missing, the system decides which google base model
                 to use.
+
                 This corresponds to the ``model`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -189,6 +260,7 @@ class TranslationServiceAsyncClient:
                 text, for example, "text/html",
                 "text/plain". If left blank, the MIME
                 type defaults to "text/html".
+
                 This corresponds to the ``mime_type`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -201,6 +273,7 @@ class TranslationServiceAsyncClient:
                 API attempts to identify the source
                 language automatically and returns the
                 source language within the response.
+
                 This corresponds to the ``source_language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -212,13 +285,13 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.translation_service.TranslateTextResponse:
+            google.cloud.translate_v3.types.TranslateTextResponse:
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any(
+        has_flattened_params = any(
             [
                 parent,
                 target_language_code,
@@ -227,7 +300,8 @@ class TranslationServiceAsyncClient:
                 mime_type,
                 source_language_code,
             ]
-        ):
+        )
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -242,8 +316,6 @@ class TranslationServiceAsyncClient:
             request.parent = parent
         if target_language_code is not None:
             request.target_language_code = target_language_code
-        if contents is not None:
-            request.contents = contents
         if model is not None:
             request.model = model
         if mime_type is not None:
@@ -251,6 +323,9 @@ class TranslationServiceAsyncClient:
         if source_language_code is not None:
             request.source_language_code = source_language_code
 
+        if contents:
+            request.contents.extend(contents)
+
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
         rpc = gapic_v1.method_async.wrap_method(
@@ -286,7 +361,7 @@ class TranslationServiceAsyncClient:
         r"""Detects the language of text within a request.
 
         Args:
-            request (:class:`~.translation_service.DetectLanguageRequest`):
+            request (:class:`google.cloud.translate_v3.types.DetectLanguageRequest`):
                 The request object. The request message for language
                 detection.
             parent (:class:`str`):
@@ -304,6 +379,7 @@ class TranslationServiceAsyncClient:
                 Only models within the same region (has same
                 location-id) can be used. Otherwise an INVALID_ARGUMENT
                 (400) error is returned.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -318,6 +394,7 @@ class TranslationServiceAsyncClient:
                 ``projects/{project-number-or-id}/locations/{location-id}/models/language-detection/default``.
 
                 If not specified, the default model is used.
+
                 This corresponds to the ``model`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -326,12 +403,14 @@ class TranslationServiceAsyncClient:
                 text, for example, "text/html",
                 "text/plain". If left blank, the MIME
                 type defaults to "text/html".
+
                 This corresponds to the ``mime_type`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             content (:class:`str`):
                 The content of the input stored as a
                 string.
+
                 This corresponds to the ``content`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -343,7 +422,7 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.translation_service.DetectLanguageResponse:
+            google.cloud.translate_v3.types.DetectLanguageResponse:
                 The response message for language
                 detection.
 
@@ -351,7 +430,8 @@ class TranslationServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, model, mime_type, content]):
+        has_flattened_params = any([parent, model, mime_type, content])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -406,7 +486,7 @@ class TranslationServiceAsyncClient:
         translation.
 
         Args:
-            request (:class:`~.translation_service.GetSupportedLanguagesRequest`):
+            request (:class:`google.cloud.translate_v3.types.GetSupportedLanguagesRequest`):
                 The request object. The request message for discovering
                 supported languages.
             parent (:class:`str`):
@@ -425,6 +505,7 @@ class TranslationServiceAsyncClient:
                 Only models within the same region (have same
                 location-id) can be used, otherwise an INVALID_ARGUMENT
                 (400) error is returned.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -443,6 +524,7 @@ class TranslationServiceAsyncClient:
                 Returns languages supported by the specified model. If
                 missing, we get supported languages of Google general
                 base (PBMT) model.
+
                 This corresponds to the ``model`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -452,6 +534,7 @@ class TranslationServiceAsyncClient:
                 of supported languages. If missing, then
                 display names are not returned in a
                 response.
+
                 This corresponds to the ``display_language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -463,7 +546,7 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.translation_service.SupportedLanguages:
+            google.cloud.translate_v3.types.SupportedLanguages:
                 The response message for discovering
                 supported languages.
 
@@ -471,7 +554,8 @@ class TranslationServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, model, display_language_code]):
+        has_flattened_params = any([parent, model, display_language_code])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -500,6 +584,7 @@ class TranslationServiceAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -536,7 +621,7 @@ class TranslationServiceAsyncClient:
         of the call.
 
         Args:
-            request (:class:`~.translation_service.BatchTranslateTextRequest`):
+            request (:class:`google.cloud.translate_v3.types.BatchTranslateTextRequest`):
                 The request object. The batch translation request.
 
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -546,15 +631,13 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.translation_service.BatchTranslateResponse``:
-                Stored in the
-                [google.longrunning.Operation.response][google.longrunning.Operation.response]
-                field returned by BatchTranslateText if at least one
-                sentence is translated successfully.
+                The result type for the operation will be :class:`google.cloud.translate_v3.types.BatchTranslateResponse` Stored in the
+                   [google.longrunning.Operation.response][google.longrunning.Operation.response]
+                   field returned by BatchTranslateText if at least one
+                   sentence is translated successfully.
 
         """
         # Create or coerce a protobuf request object.
@@ -603,14 +686,14 @@ class TranslationServiceAsyncClient:
         Returns NOT_FOUND, if the project doesn't exist.
 
         Args:
-            request (:class:`~.translation_service.CreateGlossaryRequest`):
+            request (:class:`google.cloud.translate_v3.types.CreateGlossaryRequest`):
                 The request object. Request message for CreateGlossary.
             parent (:class:`str`):
                 Required. The project name.
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            glossary (:class:`~.translation_service.Glossary`):
+            glossary (:class:`google.cloud.translate_v3.types.Glossary`):
                 Required. The glossary to create.
                 This corresponds to the ``glossary`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -623,18 +706,19 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.translation_service.Glossary``: Represents a
-                glossary built from user provided data.
+                :class:`google.cloud.translate_v3.types.Glossary`
+                Represents a glossary built from user provided data.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, glossary]):
+        has_flattened_params = any([parent, glossary])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -691,12 +775,13 @@ class TranslationServiceAsyncClient:
         doesn't exist.
 
         Args:
-            request (:class:`~.translation_service.ListGlossariesRequest`):
+            request (:class:`google.cloud.translate_v3.types.ListGlossariesRequest`):
                 The request object. Request message for ListGlossaries.
             parent (:class:`str`):
                 Required. The name of the project
                 from which to list all of the
                 glossaries.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -708,7 +793,7 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListGlossariesAsyncPager:
+            google.cloud.translate_v3.services.translation_service.pagers.ListGlossariesAsyncPager:
                 Response message for ListGlossaries.
                 Iterating over this object will yield
                 results and resolve additional pages
@@ -718,7 +803,8 @@ class TranslationServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -743,6 +829,7 @@ class TranslationServiceAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -779,11 +866,12 @@ class TranslationServiceAsyncClient:
         exist.
 
         Args:
-            request (:class:`~.translation_service.GetGlossaryRequest`):
+            request (:class:`google.cloud.translate_v3.types.GetGlossaryRequest`):
                 The request object. Request message for GetGlossary.
             name (:class:`str`):
                 Required. The name of the glossary to
                 retrieve.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -795,7 +883,7 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.translation_service.Glossary:
+            google.cloud.translate_v3.types.Glossary:
                 Represents a glossary built from user
                 provided data.
 
@@ -803,7 +891,8 @@ class TranslationServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -828,6 +917,7 @@ class TranslationServiceAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -859,11 +949,12 @@ class TranslationServiceAsyncClient:
         doesn't exist.
 
         Args:
-            request (:class:`~.translation_service.DeleteGlossaryRequest`):
+            request (:class:`google.cloud.translate_v3.types.DeleteGlossaryRequest`):
                 The request object. Request message for DeleteGlossary.
             name (:class:`str`):
                 Required. The name of the glossary to
                 delete.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -875,20 +966,19 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.translation_service.DeleteGlossaryResponse``:
-                Stored in the
-                [google.longrunning.Operation.response][google.longrunning.Operation.response]
-                field returned by DeleteGlossary.
+                The result type for the operation will be :class:`google.cloud.translate_v3.types.DeleteGlossaryResponse` Stored in the
+                   [google.longrunning.Operation.response][google.longrunning.Operation.response]
+                   field returned by DeleteGlossary.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -913,6 +1003,7 @@ class TranslationServiceAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
