@@ -50,9 +50,76 @@ class TranslationServiceAsyncClient:
     glossary_path = staticmethod(TranslationServiceClient.glossary_path)
     parse_glossary_path = staticmethod(TranslationServiceClient.parse_glossary_path)
 
-    from_service_account_file = TranslationServiceClient.from_service_account_file
+    common_billing_account_path = staticmethod(
+        TranslationServiceClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        TranslationServiceClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(TranslationServiceClient.common_folder_path)
+    parse_common_folder_path = staticmethod(
+        TranslationServiceClient.parse_common_folder_path
+    )
+
+    common_organization_path = staticmethod(
+        TranslationServiceClient.common_organization_path
+    )
+    parse_common_organization_path = staticmethod(
+        TranslationServiceClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(TranslationServiceClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        TranslationServiceClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(TranslationServiceClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        TranslationServiceClient.parse_common_location_path
+    )
+
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TranslationServiceAsyncClient: The constructed client.
+        """
+        return TranslationServiceClient.from_service_account_info.__func__(TranslationServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+        file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TranslationServiceAsyncClient: The constructed client.
+        """
+        return TranslationServiceClient.from_service_account_file.__func__(TranslationServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> TranslationServiceTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            TranslationServiceTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(TranslationServiceClient).get_transport_class,
         type(TranslationServiceClient),
@@ -117,7 +184,7 @@ class TranslationServiceAsyncClient:
         r"""Translates input text and returns translated text.
 
         Args:
-            request (:class:`~.translation_service.TranslateTextRequest`):
+            request (:class:`google.cloud.translate_v3beta1.types.TranslateTextRequest`):
                 The request object. The request message for synchronous
                 translation.
 
@@ -128,7 +195,7 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.translation_service.TranslateTextResponse:
+            google.cloud.translate_v3beta1.types.TranslateTextResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -169,7 +236,7 @@ class TranslationServiceAsyncClient:
         r"""Detects the language of text within a request.
 
         Args:
-            request (:class:`~.translation_service.DetectLanguageRequest`):
+            request (:class:`google.cloud.translate_v3beta1.types.DetectLanguageRequest`):
                 The request object. The request message for language
                 detection.
             parent (:class:`str`):
@@ -177,16 +244,17 @@ class TranslationServiceAsyncClient:
                 to a caller's project.
 
                 Format:
-                ``projects/{project-id}/locations/{location-id}`` or
-                ``projects/{project-id}``.
+                ``projects/{project-number-or-id}/locations/{location-id}``
+                or ``projects/{project-number-or-id}``.
 
                 For global calls, use
-                ``projects/{project-id}/locations/global`` or
-                ``projects/{project-id}``.
+                ``projects/{project-number-or-id}/locations/global`` or
+                ``projects/{project-number-or-id}``.
 
-                Only models within the same region (has same
-                location-id) can be used. Otherwise an INVALID_ARGUMENT
+                Only models within the same region, which have the same
+                location-id, can be used. Otherwise an INVALID_ARGUMENT
                 (400) error is returned.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -194,13 +262,14 @@ class TranslationServiceAsyncClient:
                 Optional. The language detection model to be used.
 
                 Format:
-                ``projects/{project-id}/locations/{location-id}/models/language-detection/{model-id}``
+                ``projects/{project-number-or-id}/locations/{location-id}/models/language-detection/{model-id}``
 
                 Only one language detection model is currently
                 supported:
-                ``projects/{project-id}/locations/{location-id}/models/language-detection/default``.
+                ``projects/{project-number-or-id}/locations/{location-id}/models/language-detection/default``.
 
                 If not specified, the default model is used.
+
                 This corresponds to the ``model`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -209,6 +278,7 @@ class TranslationServiceAsyncClient:
                 text, for example, "text/html",
                 "text/plain". If left blank, the MIME
                 type defaults to "text/html".
+
                 This corresponds to the ``mime_type`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -220,7 +290,7 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.translation_service.DetectLanguageResponse:
+            google.cloud.translate_v3beta1.types.DetectLanguageResponse:
                 The response message for language
                 detection.
 
@@ -228,7 +298,8 @@ class TranslationServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, model, mime_type]):
+        has_flattened_params = any([parent, model, mime_type])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -281,25 +352,26 @@ class TranslationServiceAsyncClient:
         translation.
 
         Args:
-            request (:class:`~.translation_service.GetSupportedLanguagesRequest`):
+            request (:class:`google.cloud.translate_v3beta1.types.GetSupportedLanguagesRequest`):
                 The request object. The request message for discovering
                 supported languages.
             parent (:class:`str`):
                 Required. Project or location to make a call. Must refer
                 to a caller's project.
 
-                Format: ``projects/{project-id}`` or
-                ``projects/{project-id}/locations/{location-id}``.
+                Format: ``projects/{project-number-or-id}`` or
+                ``projects/{project-number-or-id}/locations/{location-id}``.
 
                 For global calls, use
-                ``projects/{project-id}/locations/global`` or
-                ``projects/{project-id}``.
+                ``projects/{project-number-or-id}/locations/global`` or
+                ``projects/{project-number-or-id}``.
 
                 Non-global location is required for AutoML models.
 
                 Only models within the same region (have same
                 location-id) can be used, otherwise an INVALID_ARGUMENT
                 (400) error is returned.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -309,6 +381,7 @@ class TranslationServiceAsyncClient:
                 of supported languages. If missing, then
                 display names are not returned in a
                 response.
+
                 This corresponds to the ``display_language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -318,15 +391,16 @@ class TranslationServiceAsyncClient:
                 The format depends on model type:
 
                 -  AutoML Translation models:
-                   ``projects/{project-id}/locations/{location-id}/models/{model-id}``
+                   ``projects/{project-number-or-id}/locations/{location-id}/models/{model-id}``
 
                 -  General (built-in) models:
-                   ``projects/{project-id}/locations/{location-id}/models/general/nmt``,
-                   ``projects/{project-id}/locations/{location-id}/models/general/base``
+                   ``projects/{project-number-or-id}/locations/{location-id}/models/general/nmt``,
+                   ``projects/{project-number-or-id}/locations/{location-id}/models/general/base``
 
                 Returns languages supported by the specified model. If
                 missing, we get supported languages of Google general
                 base (PBMT) model.
+
                 This corresponds to the ``model`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -338,7 +412,7 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.translation_service.SupportedLanguages:
+            google.cloud.translate_v3beta1.types.SupportedLanguages:
                 The response message for discovering
                 supported languages.
 
@@ -346,7 +420,8 @@ class TranslationServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, display_language_code, model]):
+        has_flattened_params = any([parent, display_language_code, model])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -373,8 +448,9 @@ class TranslationServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -392,6 +468,56 @@ class TranslationServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def translate_document(
+        self,
+        request: translation_service.TranslateDocumentRequest = None,
+        *,
+        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> translation_service.TranslateDocumentResponse:
+        r"""Translates documents in synchronous mode.
+
+        Args:
+            request (:class:`google.cloud.translate_v3beta1.types.TranslateDocumentRequest`):
+                The request object. A document translation request.
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.translate_v3beta1.types.TranslateDocumentResponse:
+                A translated document response
+                message.
+
+        """
+        # Create or coerce a protobuf request object.
+
+        request = translation_service.TranslateDocumentRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.translate_document,
+            default_timeout=600.0,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
     async def batch_translate_text(
         self,
         request: translation_service.BatchTranslateTextRequest = None,
@@ -411,7 +537,7 @@ class TranslationServiceAsyncClient:
         of the call.
 
         Args:
-            request (:class:`~.translation_service.BatchTranslateTextRequest`):
+            request (:class:`google.cloud.translate_v3beta1.types.BatchTranslateTextRequest`):
                 The request object. The batch translation request.
 
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -421,15 +547,13 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.translation_service.BatchTranslateResponse``:
-                Stored in the
-                [google.longrunning.Operation.response][google.longrunning.Operation.response]
-                field returned by BatchTranslateText if at least one
-                sentence is translated successfully.
+                The result type for the operation will be :class:`google.cloud.translate_v3beta1.types.BatchTranslateResponse` Stored in the
+                   [google.longrunning.Operation.response][google.longrunning.Operation.response]
+                   field returned by BatchTranslateText if at least one
+                   sentence is translated successfully.
 
         """
         # Create or coerce a protobuf request object.
@@ -464,6 +588,76 @@ class TranslationServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def batch_translate_document(
+        self,
+        request: translation_service.BatchTranslateDocumentRequest = None,
+        *,
+        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Translates a large volume of documents in
+        asynchronous batch mode. This function provides real-
+        time output as the inputs are being processed. If caller
+        cancels a request, the partial results (for an input
+        file, it's all or nothing) may still be available on the
+        specified output location.
+        This call returns immediately and you can use
+        google.longrunning.Operation.name to poll the status of
+        the call.
+
+        Args:
+            request (:class:`google.cloud.translate_v3beta1.types.BatchTranslateDocumentRequest`):
+                The request object. The BatchTranslateDocument request.
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be :class:`google.cloud.translate_v3beta1.types.BatchTranslateDocumentResponse` Stored in the
+                   [google.longrunning.Operation.response][google.longrunning.Operation.response]
+                   field returned by BatchTranslateDocument if at least
+                   one document is translated successfully.
+
+        """
+        # Create or coerce a protobuf request object.
+
+        request = translation_service.BatchTranslateDocumentRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.batch_translate_document,
+            default_timeout=600.0,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            translation_service.BatchTranslateDocumentResponse,
+            metadata_type=translation_service.BatchTranslateDocumentMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def create_glossary(
         self,
         request: translation_service.CreateGlossaryRequest = None,
@@ -478,14 +672,14 @@ class TranslationServiceAsyncClient:
         Returns NOT_FOUND, if the project doesn't exist.
 
         Args:
-            request (:class:`~.translation_service.CreateGlossaryRequest`):
+            request (:class:`google.cloud.translate_v3beta1.types.CreateGlossaryRequest`):
                 The request object. Request message for CreateGlossary.
             parent (:class:`str`):
                 Required. The project name.
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            glossary (:class:`~.translation_service.Glossary`):
+            glossary (:class:`google.cloud.translate_v3beta1.types.Glossary`):
                 Required. The glossary to create.
                 This corresponds to the ``glossary`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -498,18 +692,19 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.translation_service.Glossary``: Represents a
-                glossary built from user provided data.
+                :class:`google.cloud.translate_v3beta1.types.Glossary`
+                Represents a glossary built from user provided data.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, glossary]):
+        has_flattened_params = any([parent, glossary])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -567,21 +762,47 @@ class TranslationServiceAsyncClient:
         doesn't exist.
 
         Args:
-            request (:class:`~.translation_service.ListGlossariesRequest`):
+            request (:class:`google.cloud.translate_v3beta1.types.ListGlossariesRequest`):
                 The request object. Request message for ListGlossaries.
             parent (:class:`str`):
                 Required. The name of the project
                 from which to list all of the
                 glossaries.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             filter (:class:`str`):
                 Optional. Filter specifying
-                constraints of a list operation.
-                Filtering is not supported yet, and the
-                parameter currently has no effect. If
-                missing, no filtering is performed.
+                constraints of a list operation. Specify
+                the constraint by the format of
+                "key=value", where key must be "src" or
+                "tgt", and the value must be a valid
+                language code. For multiple
+                restrictions, concatenate them by "AND"
+                (uppercase only), such as: "src=en-US
+                AND tgt=zh-CN". Notice that the exact
+                match is used here, which means using
+                'en-US' and 'en' can lead to different
+                results, which depends on the language
+                code you used when you create the
+                glossary. For the unidirectional
+                glossaries, the "src" and "tgt" add
+                restrictions on the source and target
+                language code separately. For the
+                equivalent term set glossaries, the
+                "src" and/or "tgt" add restrictions on
+                the term set.
+                For example: "src=en-US AND tgt=zh-CN"
+                will only pick the unidirectional
+                glossaries which exactly match the
+                source language code as "en-US" and the
+                target language code "zh-CN", but all
+                equivalent term set glossaries which
+                contain "en-US" and "zh-CN" in their
+                language set will be picked. If missing,
+                no filtering is performed.
+
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -593,7 +814,7 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListGlossariesAsyncPager:
+            google.cloud.translate_v3beta1.services.translation_service.pagers.ListGlossariesAsyncPager:
                 Response message for ListGlossaries.
                 Iterating over this object will yield
                 results and resolve additional pages
@@ -603,7 +824,8 @@ class TranslationServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, filter]):
+        has_flattened_params = any([parent, filter])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -628,8 +850,9 @@ class TranslationServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -666,11 +889,12 @@ class TranslationServiceAsyncClient:
         exist.
 
         Args:
-            request (:class:`~.translation_service.GetGlossaryRequest`):
+            request (:class:`google.cloud.translate_v3beta1.types.GetGlossaryRequest`):
                 The request object. Request message for GetGlossary.
             name (:class:`str`):
                 Required. The name of the glossary to
                 retrieve.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -682,7 +906,7 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.translation_service.Glossary:
+            google.cloud.translate_v3beta1.types.Glossary:
                 Represents a glossary built from user
                 provided data.
 
@@ -690,7 +914,8 @@ class TranslationServiceAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -713,8 +938,9 @@ class TranslationServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -746,11 +972,12 @@ class TranslationServiceAsyncClient:
         doesn't exist.
 
         Args:
-            request (:class:`~.translation_service.DeleteGlossaryRequest`):
+            request (:class:`google.cloud.translate_v3beta1.types.DeleteGlossaryRequest`):
                 The request object. Request message for DeleteGlossary.
             name (:class:`str`):
                 Required. The name of the glossary to
                 delete.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -762,20 +989,19 @@ class TranslationServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.translation_service.DeleteGlossaryResponse``:
-                Stored in the
-                [google.longrunning.Operation.response][google.longrunning.Operation.response]
-                field returned by DeleteGlossary.
+                The result type for the operation will be :class:`google.cloud.translate_v3beta1.types.DeleteGlossaryResponse` Stored in the
+                   [google.longrunning.Operation.response][google.longrunning.Operation.response]
+                   field returned by DeleteGlossary.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -798,8 +1024,9 @@ class TranslationServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
